@@ -551,40 +551,53 @@ static void interface_default_folder_changed(
 	DEBUG_END();
 }
 
+static gboolean confirm_close_dialog(gpointer user_data){
+    DEBUG_BEGIN();
+
+    AppData *app_data = (AppData *)user_data;
+    g_return_if_fail(app_data != NULL);
+    gint result =0;
+    LocationGPSDControl *control;
+    GtkWidget *dialog = hildon_note_new_confirmation(
+                    NULL,
+    _("You are about to close eCoach but "
+    "there is currently an activity going on.\n"
+      "Are you sure you want to close?"));
+    result = gtk_dialog_run(GTK_DIALOG(dialog));
+    gtk_widget_destroy(dialog);
+    switch(result){
+    case GTK_RESPONSE_OK:
+
+        DEBUG("RESPONSE OK");
+        control = location_gpsd_control_get_default ();
+        location_gpsd_control_stop(control);
+        map_view_stop(app_data->map_view);
+        osso_deinitialize(app_data->osso);
+        gtk_main_quit();
+        break;
+    default:
+        break;
+    }
+    gtk_widget_show(app_data->window);
+    return TRUE;
+    DEBUG_END();
+
+}
 
 static void interface_confirm_close(GtkWidget *btn,GdkEvent  *event, gpointer user_data)
 {
-	GtkWidget *dialog;
+
 	LocationGPSDControl *control;
 	MapViewActivityState activity_state;
 	AppData *app_data = (AppData *)user_data;
-	gint result;
-
 	g_return_if_fail(app_data != NULL);
 	DEBUG_BEGIN();
-	
-	
 	activity_state = map_view_get_activity_state(app_data->map_view);	
 	if (activity_state == MAP_VIEW_ACTIVITY_STATE_STARTED ||
 	  activity_state == MAP_VIEW_ACTIVITY_STATE_PAUSED)
 	{
-		dialog = hildon_note_new_confirmation(
-				GTK_WINDOW(app_data->window),
-		_("You are about to close eCoach but "
-		"there is currently an activity going on.\n"
-		  "Are you sure you want to close?"));
-		gtk_widget_show_all(dialog);
-		result = gtk_dialog_run(GTK_DIALOG(dialog));
-		gtk_widget_destroy(dialog);
-		if(result == GTK_RESPONSE_OK)
-		{
-		control = location_gpsd_control_get_default ();
-		location_gpsd_control_stop(control);
-		map_view_stop(app_data->map_view);
-		osso_deinitialize(app_data->osso);
-		gtk_main_quit();
-		}
-	  
+            confirm_close_dialog(user_data);
+
 	}
 	else
 	{
@@ -596,26 +609,10 @@ static void interface_confirm_close(GtkWidget *btn,GdkEvent  *event, gpointer us
 		gtk_main_quit();
 	}
 	  
-	
-		
-/*
-	dialog = hildon_note_new_confirmation(
-			GTK_WINDOW(app_data->window),
-			_("Do you really want to close the application?"));
-
-	result = gtk_dialog_run(GTK_DIALOG(dialog));
-
-	gtk_widget_destroy(dialog);
-
-	if(result == GTK_RESPONSE_OK)
-	{
-*/		
-/*
-	}
-*/
 	DEBUG_END();
 }
 
+
 static void interface_show_map_view(
 		NavigationMenu *menu,
 		GtkTreePath *path,
